==> zio-aws-macie2_3-5.17.124.3-sources.jar: zio/aws/macie2/model/UpdateOrganizationConfigurationRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__boolean
import scala.jdk.CollectionConverters.*
final case class UpdateOrganizationConfigurationRequest(autoEnable: __boolean) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.UpdateOrganizationConfigurationRequest = {
    import UpdateOrganizationConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.UpdateOrganizationConfigurationRequest
      .builder()
      .autoEnable(__boolean.unwrap(autoEnable): java.lang.Boolean)
      .build()
  }
  def asReadOnly
      : zio.aws.macie2.model.UpdateOrganizationConfigurationRequest.ReadOnly =
    zio.aws.macie2.model.UpdateOrganizationConfigurationRequest
      .wrap(buildAwsValue())
}
object UpdateOrganizationConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.UpdateOrganizationConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.macie2.model.UpdateOrganizationConfigurationRequest =
      zio.aws.macie2.model.UpdateOrganizationConfigurationRequest(autoEnable)
    def autoEnable: __boolean
    def getAutoEnable: ZIO[Any, Nothing, __boolean] = ZIO.succeed(autoEnable)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.UpdateOrganizationConfigurationRequest
  ) extends zio.aws.macie2.model.UpdateOrganizationConfigurationRequest.ReadOnly {
    override val autoEnable: __boolean =
      zio.aws.macie2.model.primitives.__boolean(impl.autoEnable())
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.UpdateOrganizationConfigurationRequest
  ): zio.aws.macie2.model.UpdateOrganizationConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-macie2_3-5.19.7.2-sources.jar: zio/aws/macie2/model/UpdateOrganizationConfigurationRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__boolean
import scala.jdk.CollectionConverters.*
final case class UpdateOrganizationConfigurationRequest(autoEnable: __boolean) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.UpdateOrganizationConfigurationRequest = {
    import UpdateOrganizationConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.UpdateOrganizationConfigurationRequest
      .builder()
      .autoEnable(autoEnable: java.lang.Boolean)
      .build()
  }
  def asReadOnly
      : zio.aws.macie2.model.UpdateOrganizationConfigurationRequest.ReadOnly =
    zio.aws.macie2.model.UpdateOrganizationConfigurationRequest
      .wrap(buildAwsValue())
}
object UpdateOrganizationConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.UpdateOrganizationConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.macie2.model.UpdateOrganizationConfigurationRequest =
      zio.aws.macie2.model.UpdateOrganizationConfigurationRequest(autoEnable)
    def autoEnable: __boolean
    def getAutoEnable: ZIO[Any, Nothing, __boolean] = ZIO.succeed(autoEnable)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.UpdateOrganizationConfigurationRequest
  ) extends zio.aws.macie2.model.UpdateOrganizationConfigurationRequest.ReadOnly {
    override val autoEnable: __boolean = impl.autoEnable(): __boolean
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.UpdateOrganizationConfigurationRequest
  ): zio.aws.macie2.model.UpdateOrganizationConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}
